@@ -477,7 +477,7 @@ def create_new_position_flag(df,days):
         df['DaysSincePositionStart'].fillna(999)
         df['new_position'] = 0
         df.loc[df['DaysSincePositionStart']< days,'new_position'] = 1
-        df.drop('DaysSincePositionStart',inplace=True)
+        df.drop('DaysSincePositionStart',inplace=True,axis=1)
     else:
         logging.info('Column not found, no changes were made.')
     return df
